% [t, pulse] = GausPulse(resolution, Fc, BW, PRP, R, FCC, k)
%
% this function generates a gauss windowed sine UWB pulse, with :
%  resolution : temporal resolution in s
%  center frequency and BW in Hz  
%  R   : R antenna impedance in Ohms (default value is R   =  50   )
%  FCC : FCC limit in dBm/MHz        (default value is FCC = -41.3 )
%  k   : PSD attenuation @ k dB      (default value is k   = -10   )
%
%
% author : samuel.dubouloz@cea.fr
%         CEA-LETI - April, 2004
%

function [t, pulse] = GausPulse(resolution, Fc, BW, PRP, R, FCC, k)

if(nargin == 4), k = -10; FCC = -41.3; R = 50; end 
if(nargin == 5), k = -10; FCC = -41.3; end
if(nargin == 6), k = -10; end

alpha = 1 / ( 2*sqrt(-log(10^(k/10))) );
Tau   = 1/(alpha*BW*sqrt(2)*pi);
Vmax  = sqrt(2*R*PRP*10^((FCC-90)/10))/(Tau*sqrt(pi));

t =[-5*Tau:resolution:5*Tau];
pulse = Vmax * sin(2*pi*Fc*t).*exp(-(t./Tau).^2);
